@@ -984,7 +984,7 @@ class NumerousAdminClient(NumerousClient):
         ))
 
     def listen_executions(self):
-        for doc in self._base_client.ListenExecutions():
+        for doc in self._base_client.ListenExecutions(spm_pb2.Empty()):
             yield json.loads(doc)
 
 
